@@ -11,10 +11,12 @@ from .notemptyvalidator import NotEmptyValidator
 from .notzerovalidator import NotZeroValidator
 from .pathvalidator import PathValidator
 from .regexvalidators import FloatListValidator, IntListValidator
+from .regexpatternvalidator import RegexPatternValidator
 
 __all__ = ["PathValidator",
            "NotEmptyValidator",
            "IntListValidator",
            "FloatListValidator",
            "NotZeroValidator",
-           "CompositeValidator"]
+           "CompositeValidator",
+           "RegexPatternValidator"]
