@@ -11,6 +11,7 @@ from .optionalwidget import OptionalWidget
 from .singlelinetextedit import SingleLineTextEdit
 from .mappedcheckbox import MappedCheckBox
 from .promptlineedit import PromptLineEdit
+from .logtextedit import LogTextEdit
 from .flagselectionwidget import FlagSelectionWidget
 from .stringornumberwidget import StringOrNumberWidget
 from .iconlabel import IconLabel
@@ -39,6 +40,7 @@ __all__ = ["Image",
            "SingleLineTextEdit",
            "MappedCheckBox",
            "PromptLineEdit",
+           "LogTextEdit",
            "FlagSelectionWidget",
            "StringOrNumberWidget",
            "IconLabel",
