@@ -3,12 +3,10 @@
 @author: Philipp Temminghoff
 """
 
-from typing import Union
+from qtpy import QtGui, QtCore
 
-import qtawesome as qta
-from qtpy import QtGui
-
-from prettyqt import gui
+from prettyqt import gui, core
+from prettyqt.utils import icons
 
 
 class StandardItem(QtGui.QStandardItem):
@@ -31,14 +29,21 @@ class StandardItem(QtGui.QStandardItem):
         self.setData(state["data"])
         self.set_icon(state["icon"])
 
-    def set_icon(self, icon: Union[QtGui.QIcon, str, None]):
+    def clone(self):
+        item = self.__class__()
+        ba = QtCore.QByteArray()
+        ds = QtCore.QDataStream(ba, core.IODevice.WriteOnly)
+        ds << self
+        ds = QtCore.QDataStream(ba)
+        ds >> item
+        assert type(item) == StandardItem
+        return item
+
+    def set_icon(self, icon: icons.IconType):
         """set the icon for the action
 
         Args:
             icon: icon to use
         """
-        if not icon:
-            icon = gui.Icon()
-        elif isinstance(icon, str):
-            icon = qta.icon(icon)
+        icon = icons.get_icon(icon)
         self.setIcon(icon)
