@@ -3,13 +3,11 @@
 @author: Philipp Temminghoff
 """
 
-from typing import Union
 
-import qtawesome as qta
-from qtpy import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtWidgets
 
-from prettyqt import core, gui
-from prettyqt.utils import bidict
+from prettyqt import core
+from prettyqt.utils import bidict, icons
 
 PRIORITIES = bidict(low=QtWidgets.QAction.LowPriority,
                     normal=QtWidgets.QAction.NormalPriority,
@@ -26,7 +24,11 @@ QtWidgets.QAction.__bases__ = (core.Object,)
 
 class Action(QtWidgets.QAction):
 
-    def __init__(self, parent=None, text="", icon=None, shortcut="", tooltip=""):
+    def __init__(self, parent=None,
+                 text: str = "",
+                 icon: icons.IconType = None,
+                 shortcut: str = "",
+                 tooltip: str = ""):
         super().__init__(parent)
         self.set_text(text)
         self.set_icon(icon)
@@ -77,16 +79,13 @@ class Action(QtWidgets.QAction):
     def set_checkable(self, value: bool):
         self.setCheckable(value)
 
-    def set_icon(self, icon: Union[QtGui.QIcon, str, None]):
+    def set_icon(self, icon: icons.IconType):
         """set the icon for the action
 
         Args:
             icon: icon to use
         """
-        if not icon:
-            icon = gui.Icon()
-        elif isinstance(icon, str):
-            icon = qta.icon(icon)
+        icon = icons.get_icon(icon)
         self.setIcon(icon)
 
     def set_shortcut(self, shortcut):
@@ -102,7 +101,7 @@ class Action(QtWidgets.QAction):
         Allowed values are "low", "normal", "high"
 
         Args:
-            mode: priority for the action
+            priority: priority for the action
 
         Raises:
             ValueError: priority does not exist
@@ -127,7 +126,7 @@ class Action(QtWidgets.QAction):
         Allowed values are "widget", "widget_with_children", "window", "application"
 
         Args:
-            mode: shortcut context
+            context: shortcut context
 
         Raises:
             ValueError: shortcut context does not exist
